size(5.0cm, 3.0cm);
import geometry;


// black and white vectors

real u = 1.0;

point
    center = (0, 0),
    black_center = (3.30,+1.00),
    white_center = (3.30,-1.00);

vector[] vv;

int n = 5;

for (int i = 0; i < n; ++i) {
    vv.push(u * expi(i * (pi/n)));
}

bool[] vv_are_black = new bool[] { true, false, true, false, true };

vector[] black_vv, white_vv;
vector all_offset, black_offset, white_offset;

for (int i = 0; i < n; ++i) {
    all_offset += vv[i] / 2;
    if (vv_are_black[i]) {
        black_vv.push(vv[i]);
        black_offset += vv[i] / 2;
    } else {
        white_vv.push(vv[i]);
        white_offset += vv[i] / 2;
    }
}


// vertices

point[] build_vertices(point start, vector[] sides) {
    point[] points;
    for (int i = 0; i < sides.length; ++i) {
        start += sides[i];
        points.push(start);
    }
    for (int i = 0; i < sides.length; ++i) {
        start -= sides[i];
        points.push(start);
    }
    points.cyclic = true;
    return points;
}

point[] pp = build_vertices(center - all_offset, vv);
point[] black_pp = build_vertices(black_center - black_offset, black_vv);
point[] white_pp = build_vertices(white_center - white_offset, white_vv);


// borders

real w = 0.10;

// assume pp.cyclic
point lefter(point pp[], int index) {
    vector a = unit(pp[index] - pp[index-1]);
    vector b = unit(pp[index] - pp[index+1]);
    return pp[index] + w/2 * unit(I*a - I*b) / ((-a/b)^0.5).x;
}
point righter(point pp[], int index) {
    vector a = unit(pp[index] - pp[index-1]);
    vector b = unit(pp[index] - pp[index+1]);
    return pp[index] + w/2 * unit(I*b - I*a) / ((-a/b)^0.5).x;
}
path lefter_border(point pp[]) {
    guide border = nullpath;
    for (int i = 0; i < pp.length; ++i) {
        border = border -- lefter(pp, i);
    }
    return border--cycle;
}
path righter_border(point pp[]) {
    guide border = nullpath;
    for (int i = 0; i < pp.length; ++i) {
        border = border -- righter(pp, i);
    }
    return border--cycle;
}


// draw

{ // draw black pieces of border
    path thick_border(int ii[]) {
        guide border = nullpath;
        for (int j = 0 ; j < ii.length; ++j) {
            border = righter(pp, ii[j]) -- border -- lefter(pp, ii[j]);
        }
        return border--cycle;
    }
    int start_i = 0;
    for (int i = 0; i < vv.length; ++i) {
        if (!vv_are_black[i]) {
            start_i = i;
            break;
        }
    }
    int ii[];
    for (int ix = 0; ix <= pp.length; ++ix) {
        int i = start_i + ix;
        if (!vv_are_black[i%n]) {
            if (ii.length > 1) {
                fill(thick_border(ii), black);
            }
            ii = new int[]{};
        }
        ii.push(i);
    }
}
draw(lefter_border(pp));
draw(righter_border(pp));

fill(lefter_border(black_pp) ^^ reverse(righter_border(black_pp)), black);
draw(lefter_border(black_pp));
draw(righter_border(black_pp));
label("$B$", black_center);

draw(lefter_border(white_pp));
draw(righter_border(white_pp));
label("$W$", white_center);

